﻿using Infragistics.Controls.Charts;
using KB7745_SampleApp1.Model;
using System;
using System.Collections.Generic;
using System.Globalization;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Data;

namespace KB7745_SampleApp1
{
    internal class CrosshairPointToAxisCoordinate : IMultiValueConverter
    {
        public object Convert(object[] values, Type targetType, object parameter, CultureInfo culture)
        {
            if (values == null || values.Length != 2) return Binding.DoNothing;
            if (values[0] == null || values[1] == null) return Binding.DoNothing;

            if (values[0].GetType() != typeof(Point)) return Binding.DoNothing;
            Point crosshairPoint = (Point)values[0];
            if (Double.IsNaN(crosshairPoint.X) || Double.IsNaN(crosshairPoint.Y))
            {
                return Binding.DoNothing;
            }

            Series series = values[1] as Series;
            if (series == null) return Binding.DoNothing;

            // 近傍データ点を取得する。
            SampleCategoryDataItem dataPoint = series.GetItem(crosshairPoint) as SampleCategoryDataItem;
            if (dataPoint == null) return Binding.DoNothing;

            // Y軸を取得する。
            NumericYAxis yAxis = series.GetAxes().OfType<NumericYAxis>().FirstOrDefault();
            if(yAxis == null) return Binding.DoNothing;

            // CrosshairPointからY軸値を取得する。
            double yValue = (yAxis.ActualMaximumValue - yAxis.ActualMinimumValue) * (1.0 - crosshairPoint.Y) + yAxis.ActualMinimumValue;

            return String.Format("(X, Y)=({0}, {1})", dataPoint.Category, yValue);
        }

        public object[] ConvertBack(object value, Type[] targetTypes, object parameter, CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }
}
